==> redisson-3.6.5-sources.jar: org/redisson/reactive/RedissonReadWriteLockReactive.java <==
/**
 * Copyright 2018 Nikita Koksharov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.redisson.reactive;

import org.redisson.RedissonReadWriteLock;
import org.redisson.api.RLockAsync;
import org.redisson.api.RLockReactive;
import org.redisson.api.RReadWriteLock;
import org.redisson.api.RReadWriteLockReactive;
import org.redisson.command.CommandAsyncExecutor;
import org.redisson.command.CommandReactiveExecutor;

/**
 * 
 * @author Nikita Koksharov
 *
 */
public class RedissonReadWriteLockReactive extends RedissonExpirableReactive implements RReadWriteLockReactive {

    private final RReadWriteLock instance;
    
    public RedissonReadWriteLockReactive(CommandReactiveExecutor commandExecutor, String name) {
        super(commandExecutor, name);
        this.instance = new RedissonReadWriteLock(commandExecutor, name);
    }

    @Override
    public RLockReactive readLock() {
        return new RedissonLockReactive(commandExecutor, getName()) {
            @Override
            protected RLockAsync createLock(CommandAsyncExecutor connectionManager, String name) {
                return instance.readLock();
            }
        };
    }

    @Override
    public RLockReactive writeLock() {
        return new RedissonLockReactive(commandExecutor, getName()) {
            @Override
            protected RLockAsync createLock(CommandAsyncExecutor connectionManager, String name) {
                return instance.writeLock();
            }
        };
    }

    
}

==> redisson-3.13.1-sources.jar: org/redisson/reactive/RedissonReadWriteLockReactive.java <==
/**
 * Copyright (c) 2013-2020 Nikita Koksharov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.redisson.reactive;

import org.redisson.RedissonReadWriteLock;
import org.redisson.api.RLockReactive;
import org.redisson.api.RReadWriteLock;
import org.redisson.api.RReadWriteLockReactive;

/**
 * 
 * @author Nikita Koksharov
 *
 */
public class RedissonReadWriteLockReactive implements RReadWriteLockReactive {

    private final RReadWriteLock instance;
    private final CommandReactiveExecutor commandExecutor;
    
    public RedissonReadWriteLockReactive(CommandReactiveExecutor commandExecutor, String name) {
        this.commandExecutor = commandExecutor;
        this.instance = new RedissonReadWriteLock(commandExecutor, name);
    }

    @Override
    public RLockReactive readLock() {
        return ReactiveProxyBuilder.create(commandExecutor, instance.readLock(), RLockReactive.class);
    }

    @Override
    public RLockReactive writeLock() {
        return ReactiveProxyBuilder.create(commandExecutor, instance.writeLock(), RLockReactive.class);
    }

    
}
